function H = Hdelta_r(R,baselines,LOS)

% H = Hdelta_r(R,baselines,LOS) Calculates the linearized observation
% matrix for the deltarange measurements
% 
% Inputs:
%   R:          3 x 3 rotation matrix representing the rotation from body_hat to ecef
%   baselines:  3 x nBL matrix of baseline column vectors
%   LOS:    	Matrix of column vectors representing the unit LOS vectors
%               pointing from the reciever to the GPS SVs
%
% Outputs:
%   H:          nLOS + nBL x 3 linearized observation matrix for the
%               deltarange measurements
%
% Author:    Tale Sundlister
% Date:      June 2012
% ________________________________________________________________
%
% Copyright (C) 2012 Tale Sundlister
% 
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
% 
% E-mail: tale.sundlisater@gmail.com

nLOS = size(LOS,2);
nBL = size(baselines,2);

H = zeros(nLOS*nBL,3);
for j = 1:nBL
    for i = 1:nLOS
        H(nLOS*(j-1)+i,:) = -2*LOS(:,i)'*R*Smtrx(baselines(:,j));
    end
end