function R = Rsphere2ecef(phi, theta)
% R = Rsphere2ecef(phi, theta) computes the rotation matrix 
% from spherical NED to ECEF from latitude phi [rad] and longitude theta [rad]
%
% Inputs:
%   phi:    elevation angle (latitude) [rad]
%   theta:  azimuth angle (longitude) [rad]
%
% Output:
%   R:      3x3 rotation matrix representing the rotation from spherical
%           NED to ECEF
%
% Author:    Tale Sundlister
% Date:      30 May 2012
% ________________________________________________________________
%
% Copyright (C) 2012 Tale Sundlister
% 
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
% 
% E-mail: tale.sundlisater@gmail.com

s_ph = sin(phi);
c_ph = cos(phi);
s_th = sin(theta);
c_th = cos(theta);
R = [-s_ph*c_th -s_th -c_ph*c_th;
     -s_ph*s_th  c_th -c_ph*s_th;
      c_ph       0    -s_ph];