function ADOP = adop(LOS)

% ADOP = adop(LOS) Calculates Attitude Dilution Of Precision for a given
% GPS SV constellation. Assumes an ideal baseline configuration with the
% property B*B' = l*eye(nBL) where B is the matrix of column baseline
% vectors and l is the effective baseline length.
% 
% Inputs:
%   LOS:	Matrix of column vectors representing the unit LOS vectors
%           pointing from the reciever to the GPS SVs
%
% Outputs:
%   ADOP:   Attitude Dilution Of Precision, a value representing the GPS SV
%           constellation and baseline configuration contributions to the
%           attitude uncertainty
%
% Author:    Tale Sundlister
% Date:      June 2012
% ________________________________________________________________
%
% Copyright (C) 2012 Tale Sundlister
% 
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
% 
% E-mail: tale.sundlisater@gmail.com

n = size(LOS,2);

ADOP = sqrt(trace(inv(n*eye(n) - LOS'*LOS)));