function spherical = cart2sphere(cartesian)

% spherical = cart2sphere(cartesian)
% Converts a set of cartesian coordinates to spherical coordinates
% 
% Inputs:
%   cartesian:	3-vector of cartesian coordinates [x y z]
%
% Outputs:
%   spherical:  3x1 vector of spherical coordinates [r phi theta] where:
%               r:      radius from origo
%               phi:	elevation angle (latitude) [rad]
%               theta:	azimuth angle (longitude) [rad]
%               
%
% Author:    Tale Sundlister
% Date:      June 2012
% ________________________________________________________________
%
% Copyright (C) 2012 Tale Sundlister
% 
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
% 
% E-mail: tale.sundlisater@gmail.com

x = cartesian(1);
y = cartesian(2);
z = cartesian(3);

r = norm(cartesian);

theta = atan2(y,x);
phi = acos(z/r);

spherical = [r phi theta]';