function C = closestpoint(A, B, P)

% closest = closestpoint(A, B, P)
% Computes the point C on the line segment between points A and B that is 
% closest to the point P
% 
% Inputs:
%   A:  3x1 position vector of the point A
%   B:  3x1 position vector of the point B
%   P:  3x1 position vector of the point P
%
% Outputs:
%   C:  3x1 position vector of the point C
%
% Author:    Tale Sundlister
% Date:      June 2012
% ________________________________________________________________
%
% Copyright (C) 2012 Tale Sundlister
% 
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
% 
% E-mail: tale.sundlisater@gmail.com


AP = P - A;         % Vector from A to P
AB = B - A;         % Vector from A to B

ab_sq = AB'*AB;     % Dot product of AB with itself
ap_ab = AP'*AB;     % Dot product of AP and AB

t = ap_ab/ab_sq;    % Scale factor

% Is the closest point C on the line through A and B inside the line segment
% between A and B. If not, C is either A or B
if(t < 0)
    t = 0;
elseif (t > 1)
    t = 1;
end

C = A + AB*t;