function B = colnormalize(A)

% B = colnormalize(A)
% Normalizes column vectors in matrix A to unit vectors
% 
% Inputs:
%   A:  Matrix of column vectors
%
% Outputs:
%   B:  Matrix of column unit vectors parallel to the column vectors in A
%
% Author:    Tale Sundlister
% Date:      June 2012
% ________________________________________________________________
%
% Copyright (C) 2012 Tale Sundlister
% 
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
% 
% E-mail: tale.sundlisater@gmail.com

B = NaN*ones(size(A));
for i = 1:size(A,2)
    if(all(A(:,i) == 0))
        % Zero vectors remain zero vectors
        B(:,i) = 0;
    else
        B(:,i) = A(:,i)/norm(A(:,i));
    end
end