function[a e M i RAAN w] = eci2koeC(pos, vel)
% [a e M i RAAN w] = eci2koeC(pos, vel) converts Cartesian ECI coordinates
% to Orbit Parameters, assumes circular orbit (e ? 0)
%
% Author:    Tale Sundlister
% Date:      May 2012
% ________________________________________________________________
%
% Copyright (C) 2012 Tale Sundlister
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% E-mail: tale.sundlisater@gmail.com

global wgs84_GM;	% Gravitational constant [m^3/s^2]

e_tol = 1e-2;

h = Smtrx(pos)*vel;     % Vector perpendicular to orbit plane

n = [-h(2) h(1) 0]';	% Vector pointing towards the ascending node

v = norm(vel);          % Magnitude of velocity
r = norm(pos);          % Magnitude of position

% Eccentricity vector pointing towards periapsis
e_vect = (1/wgs84_GM)*((v^2 - wgs84_GM/r)*pos - (pos'*vel)*vel);

% Auxiliary expression
E_a = (v^2)/2 - wgs84_GM/r;

% Semimajor axis
a = -wgs84_GM/(2*E_a);

% Eccentricity
e = norm(e_vect);

% Inclination
i = acos(h(3)/norm(h));

if(e > e_tol)   % Elliptic orbit
    
    warning('eci2koeC:elliptic','orbit not circular')
end


e = 0;
w = 0;

if(i == 0)      % Equatorial circular orbit
    RAAN = 0;
    nu = acos(pos(1)/norm(pos));
    if(vel(1) > 0)
        nu = 2*pi - nu;
    end
else            % Circular orbit
    RAAN = acos(n(1)/norm(n));
    if(n(2) < 0)
        RAAN = 2*pi - RAAN;
    end
    nu = acos(n'*pos/(norm(n)*norm(pos)));
    if(n'*vel > 0)
        nu = 2*pi - nu;
    end
end
M = nu;
