function R = eci2orbit(r, v)

% R = eci2orbit(r, v)
% Calculates rotation matrix from ECI frame to ORBIT frame
% 
% Inputs:
%   r:  3x1 position vector of satellite in ECI
%   v:	3x1 velocity vector of satellite in ECI
%
% Outputs:
%   R:  3x3 rotation matrix representing the rotation from ECI to ORBIT
%
% Author:    Tale Sundlister
% Date:      June 2012
% ________________________________________________________________
%
% Copyright (C) 2012 Tale Sundlister
% 
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
% 
% E-mail: tale.sundlisater@gmail.com

% Find y_o vector in ECI by finding orbit antinormal and normalizing
vxr = Smtrx(v)*r;
y_o = vxr/norm(vxr);

% z_o vector in ECI is the normalized negative position vector
z_o = -r/norm(r);

% x_o completes the right-hand coordinate system
x_o = Smtrx(y_o)*z_o;

% The rotation matrix from ORBIT to ECI is the matrix of orthogonal
% ORBIT frame unit vectors, decomposed in ECI frame. The rotation matrix
% from ECI to ORBIT is this matrix transposed.
R = [x_o y_o z_o]';