function b_p = prop_bias(delta_eps,gyro,gyro_b,P)

% b_p = prop_bias(delta_eps,gyro,gyro_b,P) Calculates the delta_epsilon
% propagation bias due to 2nd-order elements in the function x_dot = f(x,u)
%
% Inputs:
%   delta_eps:  vector part of the error quaternion delta q
%   gyro:       3x1 gyro measurement vector
%   gyro_b:     3x1 gyro bias vector
%   P:          covariance matrix
%
% Outputs:
%   b_p:        delta epsilon propagation bias due to 2nd-order elements in
%               the function x_dot = f(x,u)
%
% Author:    Tale Sundlister
% Date:      June 2012
% ________________________________________________________________
%
% Copyright (C) 2012 Tale Sundlister
% 
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
% 
% E-mail: tale.sundlisater@gmail.com

% Reconstruct delta q from delta epsilon
eta = sqrt(1-delta_eps'*delta_eps);
eps = delta_eps;

b_p = [0 0 0]';

omega = gyro - gyro_b;

% Add d^2f/(d delta_eps_i)^2
for i = 1:3
    b_p = b_p + (0.5*(eta*eps(i)^2 - 1/eta)*omega)*P(i,i);
end

% Add d^2f/(d eps_i d b_j)
for i = 1:3
    for j = 4:6
        b_p(j-3) = b_p(j-3) + (0.5*eps(i)/eta)*P(i,j);
    end
end

% Add d^2f/(d eps_i d eps_j)
for i = 1:3
    for j = 1:3
        if(i ~= j)
            b_p = b_p - 0.25*eta*eps(i)*eps(j)*omega*P(i,j);
        end
    end
end