function q = qmult(q_1,q_2)

% q = qmult(q_1,q_2) Multiplies the given quaternions
%
% Inputs:
%   q_1:    4x1 quaternion
%   q_2:    4x1 quaternion
%
% Outputs:
%   q:      4x1 quaternion q = q_1 x q_2
%
% Author:    Tale Sundlister
% Date:      June 2012
% ________________________________________________________________
%
% Copyright (C) 2012 Tale Sundlister
% 
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
% 
% E-mail: tale.sundlisater@gmail.com
if (any(~isreal(q_1)) || any(~isreal(q_2)))
    error('Quaternion elements must be real.');
end
if any(size(q_1)~=[4,1]) || any(size(q_2)~=[4,1])
    error('Quaternion dimension must be 4-by-1.');
end

eta_1 = q_1(1);
epsilon_1 = q_1(2:4);

q_1L = [eta_1     (-epsilon_1');
        epsilon_1 (eta_1*eye(3) + Smtrx(epsilon_1))];

q = q_1L * q_2;