function vis = visible(pos, c)

% visible = visibleLOS(positions) Takes in a set of points in ECI or ECEF
% and outputs the points that are visible from the first point in the set.
% Visibility is blocked by a sphere of radius c
% 
% Inputs:
%   pos:	3 x n+1 matrix of position column vectors. The first column
%           vector is the position of the reference point. All positions
%           are in ECI or ECEF [m]
%   c:      cutoff
%
% Outputs:
%   vis:    4 x n_vis matrix. Row 1-3 are the positions visible from the
%           reference position, in ECI or ECEF. Row 4 is the index of the
%           respective position, index 1 is the first non-reference position.
%
% Author:    Tale Sundlister
% Date:      June 2012
% ________________________________________________________________
%
% Copyright (C) 2012 Tale Sundlister
% 
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
% 
% E-mail: tale.sundlisater@gmail.com

r_A = pos(:,1);         % Reference position
r_B = pos(:,2:end);     % Candidate positions

% Preallocating
closest = zeros(size(r_B));

% Find point on line segment between reference position and candidate
% position closest to origo
for i = 1:size(r_B,2)
    closest(:,i) = closestpoint(r_A, r_B(:,i), [0 0 0]');
end

viscount = 0;   % Number of accepted candidate positions

% Preallocating
vis = zeros(4,size(closest,2));

for i = 1:size(closest,2)
    dist = norm(closest(:,i));  % Distance to origo
    
    % Compare to cutoff radius
    if (dist >= c)
        % Position candidate accepted
        viscount = viscount + 1;
        vis(1:3,viscount) = r_B(:,i);
        vis(4,viscount) = i;
    end
end